@@ -3,8 +3,11 @@ from django.shortcuts import get_object_or_404
 from newscenter.models import Article, Newsroom
 
 class NewsroomFeed(Feed):
-    def get_object(self, request, newsroom, website=''):        
-        return get_object_or_404(Newsroom, slug=newsroom, website__short_name=website)
+    def get_object(self, request, newsroom, website=None):
+        try:
+            return get_object_or_404(Newsroom, slug=newsroom, website__short_name=website)
+        except:
+            return get_object_or_404(Newsroom, slug=newsroom)
 
     def title(self, obj):
         return "%s Entries" % obj.name
